SubscriberOverflow

Enum SubscriberOverflow 

pub enum SubscriberOverflow {
    DropNewest,
    DropOldest,
    Disconnect,
}
Overflow behavior for a bounded event subscription queue.

These policies are applied independently per subscriber when that subscriber’s queue is full.

Variants



DropNewest

Leave the existing queue unchanged and discard the newly published event.



DropOldest

Remove the oldest queued event and enqueue the newly published event.



Disconnect

Disconnect the subscriber and clear its queue.